@@ -147,7 +147,8 @@ getEffects<- function(x, nintn = 10, behNintn=4, getDocumentation=FALSE)
         }
         for (j in seq(along = xx$dycCovars))
         {
-            if (attr(xx$dycCovars[[j]], 'nodeSet')[1] == nodeSet)
+            if (attr(xx$dycCovars[[j]], "type") == "oneMode" &&
+				attr(xx$dycCovars[[j]], 'nodeSet')[1] == nodeSet)
             {
                 objEffects <- rbind(objEffects,
                                     createEffects("dyadObjective",
@@ -160,7 +161,8 @@ getEffects<- function(x, nintn = 10, behNintn=4, getDocumentation=FALSE)
         }
         for (j in seq(along = xx$dyvCovars))
         {
-            if (attr(xx$dyvCovars[[j]], 'nodeSet')[1] == nodeSet)
+            if (attr(xx$dyvCovars[[j]], "type") == "oneMode" &&
+				attr(xx$dyvCovars[[j]], 'nodeSet')[1] == nodeSet)
             {
                 objEffects <- rbind(objEffects,
                                     createEffects("dyadObjective",
@@ -209,7 +211,6 @@ getEffects<- function(x, nintn = 10, behNintn=4, getDocumentation=FALSE)
             }
         }
 
-### not sure we need this: if so then check relevant combinations of nodesets
         if (length(xx$cCovars) + length(xx$vCovars) +
             length(xx$dycCovars) + length(xx$dyvCovars) +
             length(types=='behavior') > 0)
@@ -266,7 +267,8 @@ getEffects<- function(x, nintn = 10, behNintn=4, getDocumentation=FALSE)
                         objEffects <-
                             rbind(objEffects,
                                   covarNetNetEff(otherName, names(xx$cCovars)[k],
-                                                 attr(xx$cCovars[[k]], 'poszvar'),
+                                                 attr(xx$cCovars[[k]],
+													  'poszvar'),
                                                  name=varname))
                     }
                 }
@@ -277,7 +279,8 @@ getEffects<- function(x, nintn = 10, behNintn=4, getDocumentation=FALSE)
                         objEffects <-
                             rbind(objEffects,
                                   covarNetNetEff(otherName, names(xx$vCovars)[k],
-                                                 attr(xx$vCovars[[k]], 'poszvar'),
+                                                 attr(xx$vCovars[[k]],
+													  'poszvar'),
                                                  name=varname))
                     }
                 }
@@ -534,7 +537,8 @@ getEffects<- function(x, nintn = 10, behNintn=4, getDocumentation=FALSE)
 
         for (j in seq(along = xx$dycCovars))
         {
-            if (all(nodeSets == attr(xx$dycCovars[[j]], 'nodeSet')))
+			if (attr(xx$dycCovars[[j]], "type") == "bipartite" &&
+				all(nodeSets == attr(xx$dycCovars[[j]], 'nodeSet')))
             {
                 objEffects <- rbind(objEffects,
                                     createEffects("dyadBipartiteObjective",
@@ -546,7 +550,8 @@ getEffects<- function(x, nintn = 10, behNintn=4, getDocumentation=FALSE)
         }
         for (j in seq(along = xx$dyvCovars))
         {
-            if (all(nodeSets == attr(xx$dyvCovars[[j]], 'nodeSet')))
+            if (attr(xx$dyvCovars[[j]], "type") == "bipartite" &&
+				all(nodeSets == attr(xx$dyvCovars[[j]], 'nodeSet')))
             {
                 objEffects <- rbind(objEffects,
                                     createEffects("dyadBipartiteObjective",
@@ -606,7 +611,6 @@ getEffects<- function(x, nintn = 10, behNintn=4, getDocumentation=FALSE)
                 rateEffects <- rbind(rateEffects, tmp$rateEff)
             }
         }
-### not sure we need this: if so then check relevant combinations of nodesets
         if (length(xx$cCovars) + length(xx$vCovars) +
             length(xx$dycCovars) + length(xx$dyvCovars) +
             length(types=='behavior') > 0)
@@ -665,9 +669,6 @@ getEffects<- function(x, nintn = 10, behNintn=4, getDocumentation=FALSE)
             objEffects$effectName <- paste(varname, ': ',
                                            objEffects$effectName, sep = '')
         }
-        ## now create the real effects, extra rows for endowment effects etc
-        ##objEffects <- createObjEffectList(objEffects, varname)
-        ##rateEffects <- createRateEffectList(rateEffects, varname)
 
         objEffects$functionName[objEffects$type == 'endow'] <-
             paste('Lost ties:',
@@ -695,12 +696,6 @@ getEffects<- function(x, nintn = 10, behNintn=4, getDocumentation=FALSE)
             objEffects <-
                 objEffects[!objEffects$shortName == "density", ]
         }
-        ##   if (attr(xx$depvars[[i]],'uponly') || attr(xx$depvars[[i]],
-        ##                                              'downonly'))
-        ##  {
-        ##     objEffects <-
-        ##        objEffects[!objEffects$shortName == "density", ]
-        ##  }
 
         rateEffects$basicRate[1:observations] <- TRUE
 
@@ -1418,4 +1413,3 @@ getBipartiteStartingVals <- function(depvar)
     list(startRate=startRate, degree=alphaf1, alpha=alpha, prec=prec, tmp=tmp,
         untrimmed = untrimmed)
 }
-
