@@ -65,13 +65,11 @@ effectsDocumentation <- function(type="html", display=type=="html",
                  "behaviorOneModeObjective",
                  "behaviorBipartiteObjective",
                  "covarBehaviorObjective",
-                 "behaviorOneModeObjective2",
-                 "behaviorBipartiteObjective2",
                  "unspecifiedBehaviorInteraction")
 
     mytab <- table(allEffects[,1])
 
-    addtorowPos <- cumsum(c(0, mytab[myorder]))[1:37]
+    addtorowPos <- cumsum(c(0, mytab[myorder]))[1:35]
     addtorowText <- names(mytab[myorder])
     if (type=="latex")
     {
@@ -103,7 +101,7 @@ effectsDocumentation <- function(type="html", display=type=="html",
         filename2 <- paste(filename,".tex", sep="", collapse="")
         includefile <- paste(filename,".include.tex", sep="", collapse="")
         includepart <- paste(filename,".include", sep="", collapse="")
-        print(xtable(y), add.to.row=add.to.row, file=includefile,
+        print(xtable::xtable(y), add.to.row=add.to.row, file=includefile,
               tabular.environment="longtable", hline.after=c(-1),
               floating=FALSE, include.rownames=FALSE)
 
@@ -125,7 +123,7 @@ effectsDocumentation <- function(type="html", display=type=="html",
     else
     {
         filename <- paste(filename,".html", sep="", collapse="")
-        print(xtable(y), add.to.row=add.to.row,
+        print(xtable::xtable(y), add.to.row=add.to.row,
               file=filename,
               type="html", hline.after=c(-1),
               sanitize.text.function=function(x){x},
