@@ -16,6 +16,7 @@
 #include "AverageAlterEffect.h"
 #include "AverageReciprocatedAlterEffect.h"
 #include "BalanceEffect.h"
+#include "BehaviorInteractionEffect.h"
 #include "BetweennessEffect.h"
 #include "CovariateAlterEffect.h"
 #include "CovariateDistance2AlterEffect.h"
@@ -52,7 +53,6 @@
 #include "OutdegreePopularityEffect.h"
 #include "OutInDegreeAssortativityEffect.h"
 #include "OutOutDegreeAssortativityEffect.h"
-#include "OutTruncEffect.h"
 #include "PopularityAlterEffect.h"
 #include "QuadraticShapeEffect.h"
 #include "ReciprocalDegreeBehaviorEffect.h"
@@ -65,6 +65,7 @@
 #include "TransitiveTiesEffect.h"
 #include "TransitiveTriadsEffect.h"
 #include "TransitiveTripletsEffect.h"
+#include "TruncatedOutdegreeEffect.h"
 #include "WWXClosureEffect.h"
 #include "WXXClosureEffect.h"
 #include "XWXClosureEffect.h"
